#include <vector>
#include <algorithm>
#include <assert.h>

using namespace std;

constexpr int INF = 1e9 + 7;

constexpr double eps = 1e-7;

struct Line {
    double k, b;

    Line(double _k = 0, double _b = 0) {
        k = _k, b = _b;
    }

    double operator()(double x) {
        return k * x + b;
    }

    bool operator<(Line l) {
        if (k != l.k) {
            return k < l.k;
        }
        return b > l.b;
    }
};

double intersectiont(Line l1, Line l2) {
    return (l2.b - l1.b) / (l1.k - l2.k);
}

struct CHT {
    vector<Line> lines;
    vector<double> points;

    CHT() {

    }

    void addLine(Line l) {
        if (!lines.empty() && l.k == lines.back().k) {
            return;
        }
        while (lines.size() > 1 && intersectiont(lines.rbegin()[1], l) <= points.back()) {
            lines.pop_back();
            points.pop_back();
        }
        if (!lines.empty()) {
            points.push_back(intersectiont(lines.back(), l));
        }
        lines.push_back(l);
    }

    double getAns(double Ma, double Mb, double ll) {
        double ans = INF;
        for (int i = 0; i < (int)points.size(); ++i) {
            if (points[i] >= ll) {
                ans = min(ans, points[i] * Ma + lines[i](points[i]) * Mb);
                if (i == 0 || points[i - 1] < ll) {
                    ans = min(ans, ll * Ma + lines[i](ll) * Mb);
                }
            }
        }
        if (points.empty() || points.back() < ll) {
            ans = min(ans, ll * Ma + lines.back()(ll) * Mb);
        }
        return ans;
    }

    vector<Line> buildAns(double ll) {
        vector<Line> linesAns;
        for (int i = 0; i < (int)points.size(); ++i) {
            if (points[i] >= ll) {
                linesAns.emplace_back(lines[i](points[i]), points[i]);
                if (i == 0 || points[i - 1] < ll) {
                    linesAns.emplace_back(lines[i](ll), ll);
                }
            }
        }
        if (points.empty() || points.back() < ll) {
            linesAns.emplace_back(lines.back()(ll), ll);
        }
        return linesAns;
    }

    double operator()(double x) {
        int pos = lower_bound(points.begin(), points.end(), x) - points.begin();
        return lines[pos](x);
    }
};

constexpr int R = 1 << 17;

double mxll[R * 2];

vector<Line> lines[R * 2];

CHT cht[R * 2];

void build() {
    for (int i = R; i < R * 2; ++i) {
        sort(lines[i].begin(), lines[i].end());
        for (auto l : lines[i]) {
            cht[i].addLine(l);
        }
    }
    for (int i = R - 1; i > 0; --i) {
        mxll[i] = max(mxll[i * 2], mxll[i * 2 + 1]);
        lines[i].resize(lines[i * 2].size() + lines[i * 2 + 1].size());
        merge(lines[i * 2].begin(), lines[i * 2].end(), lines[i * 2 + 1].begin(), lines[i * 2 + 1].end(), lines[i].begin());
        for (auto l : lines[i]) {
            cht[i].addLine(l);
        }
    }
}

double getmxll(int l, int r) {
    l += R;
    r += R;
    double ll = 0;
    while (l < r) {
        if (l & 1) {
            ll = max(ll, mxll[l]);
            l++;
        }
        if (r & 1) {
            --r;
            ll = max(ll, mxll[r]);
        }
        l >>= 1;
        r >>= 1;
    }
    return ll;
}

double getY(double x, int l, int r) {
    l += R;
    r += R;
    double y = 0;
    while (l < r) {
        if (l & 1) {
            y = max(y, cht[l](x));
            l++;
        }
        if (r & 1) {
            --r;
            y = max(y, cht[r](x));
        }
        l >>= 1;
        r >>= 1;
    }
    return y;
}

int n;

vector<int> a, b;

vector<pair<int, int>> vals;

void init(const vector<int>& A, const vector<int>& B) {
    n = A.size();
    a = A, b = B;
    for (int i = 0; i < n; ++i) {
        vals.emplace_back(a[i], b[i]);
    }
    sort(vals.begin(), vals.end());
    for (int i = 0; i < n; ++i) {
        if (vals[i].second == 0) {
            mxll[i + R] = 1 / (double)vals[i].first;
        } else {
            lines[i + R].emplace_back(-vals[i].first / (double)vals[i].second, 1 / (double)vals[i].second);
        }
    }
    build();
}

double friendDrink(const int Ma, const int Mb, const int La, const int Ra) {
    int pl = lower_bound(vals.begin(), vals.end(), make_pair(La, 0)) - vals.begin();
    int pr = lower_bound(vals.begin(), vals.end(), make_pair(Ra + 1, 0)) - vals.begin();
    if (pl == pr) {
        return 0;
    }
    double l = getmxll(pl, pr), r = INF;
    for (int _ = 0; _ < 200; ++_) {
        double m1 = l + (r - l) / 3, m2 = l + (r - l) / 3 * 2;
        double ans1 = m1 * Ma + getY(m1, pl, pr) * Mb, ans2 = m2 * Ma + getY(m2, pl, pr) * Mb;
        if (ans1 < ans2) {
            r = m2;
        }
        else {
            l = m1;
        }
    }
    return l * Ma + getY(l, pl, pr) * Mb;
}
